@@ -80,7 +80,10 @@ gboolean screenshooter_action_idle (ScreenshotData *sd)
         }
     }
 
-  if (sd->action == SAVE)
+  if (sd->action & CLIPBOARD)
+    screenshooter_copy_to_clipboard (sd->screenshot);
+
+  if (sd->action & SAVE)
     {
       const gchar *save_location;
 
@@ -92,7 +95,7 @@ gboolean screenshooter_action_idle (ScreenshotData *sd)
                                                      sd->title,
                                                      sd->timestamp,
                                                      TRUE,
-                                                     sd->action_specified);
+                                                     TRUE);
 
       if (save_location)
         {
@@ -104,10 +107,6 @@ gboolean screenshooter_action_idle (ScreenshotData *sd)
           TRACE ("New save directory: %s", sd->screenshot_dir);
         }
     }
-  else if (sd->action == CLIPBOARD)
-    {
-      screenshooter_copy_to_clipboard (sd->screenshot);
-    }
   else
     {
       GFile *temp_dir = g_file_new_for_path (g_get_tmp_dir ());
@@ -122,27 +121,10 @@ gboolean screenshooter_action_idle (ScreenshotData *sd)
 
       if (screenshot_path != NULL)
         {
-          if (sd->action == OPEN)
-            screenshooter_open_screenshot (screenshot_path, sd->app);
-          else if (sd->action == UPLOAD_IMGUR) {
-              screenshooter_upload_to_imgur   (screenshot_path,
-                                               sd->title);
-            }
-          else
-            {
-              gchar *new_last_user = NULL;
-
-              screenshooter_upload_to_zimagez (screenshot_path,
-                                               sd->last_user,
-                                               sd->title,
-                                               &new_last_user);
-
-              if (new_last_user)
-                {
-                  g_free (sd->last_user);
-                  sd->last_user = new_last_user;
-                }
-            }
+          if (sd->action & OPEN)
+            screenshooter_open_screenshot (screenshot_path, sd->app, sd->app_info);
+          else if (sd->action & UPLOAD_IMGUR)
+            screenshooter_upload_to_imgur (screenshot_path, sd->title);
         }
 
       g_object_unref (temp_dir);
